@@ -1,11 +1,13 @@
 __all__ = ('Request',)
 
 import abc
+from contextlib import suppress
 
 import requests
 from django.contrib.auth import get_user_model
 from google.auth.transport.requests import Request as GoogleRequest
 from google.oauth2 import id_token
+from rest_framework import status
 from rest_framework_simplejwt.tokens import RefreshToken
 
 
@@ -71,6 +73,24 @@ class BaseRequest(HttpClient):
         response = requests.put(self.url, json=payload, headers=self._headers, timeout=self._timeout)
         return response
 
+    def post_file(self, file):
+        file_name = file.name
+        with suppress(Exception):
+            file = getattr(file, 'file')
+        response = requests.post(
+            url=self.url,
+            data={},
+            files={"file": (file_name, file)},
+            headers=self._headers,
+            timeout=self._timeout
+        )
+        if not any((status.is_success(response.status_code), status.is_client_error(response.status_code))):
+            try:
+                raise Exception(f'{response.status_code}:{response.url}:{response.json()}')
+            except Exception:
+                raise Exception(f'{response.status_code}:{response.url}:{response.text}')
+        return response
+
     @property
     def url(self):
         domain = f'https://{self._service}-dot-{self._project}.appspot.com'
